@@ -9,6 +9,7 @@ from ibis_substrait.compiler.translate import translate
 from ibis_substrait.proto.substrait import type_pb2 as stt
 
 NULLABILITY_NULLABLE = stt.Type.Nullability.NULLABILITY_NULLABLE
+NULLABILITY_REQUIRED = stt.Type.Nullability.NULLABILITY_REQUIRED
 
 
 @pytest.fixture
@@ -96,10 +97,11 @@ def test_translate_table_expansion(compiler):
                     "baseSchema": {
                         "names": ["a", "b"],
                         "struct": {
+                            "nullability": "NULLABILITY_REQUIRED",
                             "types": [
                                 {"i32": {"nullability": "NULLABILITY_NULLABLE"}},
                                 {"i64": {"nullability": "NULLABILITY_NULLABLE"}},
-                            ]
+                            ],
                         },
                     },
                     "namedTable": {"names": ["table0"]},
@@ -208,7 +210,8 @@ def test_ibis_schema_to_substrait_schema():
                     )
                 ),
                 stt.Type(i64=stt.Type.I64(nullability=NULLABILITY_NULLABLE)),
-            ]
+            ],
+            nullability=NULLABILITY_REQUIRED,
         ),
     )
     assert translate(input) == expected
