@@ -117,7 +117,7 @@ literal_cases = pytest.mark.parametrize(
         ),
         # date
         pytest.param(
-            ibis.date(DATE),
+            ibis.date(DATE.isoformat()),
             stalg.Expression(literal=stalg.Expression.Literal(date=DATE_DAYS)),
             id="date",
         ),
@@ -303,7 +303,7 @@ def test_literal(compiler, expr, ir):
 
 
 @pytest.mark.xfail(
-    raises=ibis.common.exceptions.IbisTypeError,
+    raises=(ibis.common.exceptions.IbisTypeError, NotImplementedError),
     reason="Ibis doesn't allow decimal values through validation",
 )
 def test_decimal_literal(compiler):
